#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 cassava
version:              0.5.3.2
visibility:           public
id:                   cassava-0.5.3.2-HB0L9fb5BO3DwATcwa64JO
key:                  cassava-0.5.3.2-HB0L9fb5BO3DwATcwa64JO
license:              BSD-3-Clause
copyright:
    (c) 2012 Johan Tibell
    (c) 2012 Bryan O'\''Sullivan
    (c) 2011 MailRank, Inc.

maintainer:           https://github.com/haskell-hvr/cassava
author:               Johan Tibell
homepage:             https://github.com/haskell-hvr/cassava
synopsis:             A CSV parsing and encoding library
description:
    @cassava@ is a library for parsing and encoding [RFC 4180](https://tools.ietf.org/html/rfc4180)
    compliant [comma-separated values (CSV)](https://en.wikipedia.org/wiki/Comma-separated_values) data,
    which is a textual line-oriented format commonly used for exchanging tabular data.

    @cassava@'\''s API includes support for

    - Index-based record-conversion
    - Name-based record-conversion
    - Typeclass directed conversion of fields and records
    - Built-in field-conversion instances for standard types
    - Customizable record-conversion instance derivation via GHC generics
    - Low-level [bytestring](https://hackage.haskell.org/package/bytestring) builders (see "Data.Csv.Builder")
    - Incremental decoding and encoding API (see "Data.Csv.Incremental")
    - Streaming API for constant-space decoding (see "Data.Csv.Streaming")

    Moreover, this library is designed to be easy to use; for instance, here'\''s a
    very simple example of encoding CSV data:

    >>> Data.Csv.encode [("John",27),("Jane",28)]
    "John,27\r\nJane,28\r\n"

    Please refer to the documentation in "Data.Csv" and the included [README](#readme) for more usage examples.

category:             Text, Web, CSV
abi:                  7aa3799a5cd5df9f11eeb2079f7aa002
exposed:              True
exposed-modules:
    Data.Csv Data.Csv.Builder Data.Csv.Incremental Data.Csv.Parser
    Data.Csv.Streaming

hidden-modules:
    Data.Csv.Conversion Data.Csv.Conversion.Internal Data.Csv.Encoding
    Data.Csv.Types Data.Csv.Util

import-dirs:          /usr/lib/ghc-9.4.8/site-local/cassava-0.5.3.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/cassava-0.5.3.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/cassava-0.5.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cassava
hs-libraries:         HScassava-0.5.3.2-HB0L9fb5BO3DwATcwa64JO
depends:
    Only-0.1-2ALIOaFTuVl17VyQ33BnR1 array-0.5.4.0
    attoparsec-0.14.4-HXvPhgAZIYuDm9YtcrLhPL base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.0
    hashable-1.4.4.0-5O85VrI4oZ4EDBPYdTgwgk
    scientific-0.3.7.0-EYP4lwU6ELFEdSU4sCeddu text-2.0.2
    text-short-0.1.6-JxZmomqfmBPHr8e1Kgb0nA transformers-0.5.6.2
    unordered-containers-0.2.20-2kG5VEC3Gy42AwINT9WJ9w
    vector-0.13.1.0-Dc65CzydytHE52tdajtbOv

haddock-interfaces:   /usr/share/doc/haskell-cassava/html/cassava.haddock
haddock-html:         /usr/share/doc/haskell-cassava/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

